DriveActivity

Struct DriveActivity 

pub struct DriveActivity {
    pub actions: Option<Vec<Action>>,
    pub actors: Option<Vec<Actor>>,
    pub primary_action_detail: Option<ActionDetail>,
    pub targets: Option<Vec<Target>>,
    pub time_range: Option<TimeRange>,
    pub timestamp: Option<DateTime<Utc>>,
}
A single Drive activity comprising one or more Actions by one or more Actors on one or more Targets. Some Action groupings occur spontaneously, such as moving an item into a shared folder triggering a permission change. Other groupings of related Actions, such as multiple Actors editing one item or moving multiple files into a new folder, are controlled by the selection of a ConsolidationStrategy in the QueryDriveActivityRequest.

This type is not used in any activity, and only used as part of another schema.

Fields

actions: Option<Vec<Action>>

Details on all actions in this activity.

actors: Option<Vec<Actor>>

All actor(s) responsible for the activity.

primary_action_detail: Option<ActionDetail>

Key information about the primary action for this activity. This is either representative, or the most important, of all actions in the activity, according to the ConsolidationStrategy in the request.

targets: Option<Vec<Target>>

All Google Drive objects this activity is about (e.g. file, folder, drive). This represents the state of the target immediately after the actions occurred.

time_range: Option<TimeRange>

The activity occurred over this time range.

timestamp: Option<DateTime<Utc>>

The activity occurred at this specific time.