pub struct FileComment {
pub legacy_comment_id: Option<String>,
pub legacy_discussion_id: Option<String>,
pub link_to_discussion: Option<String>,
pub parent: Option<DriveItem>,
}Expand description
A comment on a file.
This type is not used in any activity, and only used as part of another schema.
Fields
legacy_comment_id: Option<String>The comment in the discussion thread. This identifier is an opaque string compatible with the Drive API; see https://developers.google.com/workspace/drive/v3/reference/comments/get
legacy_discussion_id: Option<String>The discussion thread to which the comment was added. This identifier is an opaque string compatible with the Drive API and references the first comment in a discussion; see https://developers.google.com/workspace/drive/v3/reference/comments/get
link_to_discussion: Option<String>The link to the discussion thread containing this comment, for example, https://docs.google.com/DOCUMENT_ID/edit?disco=THREAD_ID.
parent: Option<DriveItem>The Drive item containing this comment.