Impersonation

Struct Impersonation 

pub struct Impersonation {
    pub impersonated_user: Option<User>,
}
Information about an impersonation, where an admin acts on behalf of an end user. Information about the acting admin is not currently available.

This type is not used in any activity, and only used as part of another schema.

Fields

impersonated_user: Option<User>

The impersonated user.