pub struct QueryDriveActivityResponse {
pub activities: Option<Vec<DriveActivity>>,
pub next_page_token: Option<String>,
}Expand description
Response message for querying Drive activity.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- query activity (response)
Fields
activities: Option<Vec<DriveActivity>>List of activity requested.
next_page_token: Option<String>Token to retrieve the next page of results, or empty if there are no more results in the list.